
def soma(valorx,valory):
    return valorx+valory

def subtracao(valorx,valory):
    return valorx-valory

def multiplicacao(valorx,valory):
    return valorx*valory

def divisao(valorx,valory):
    return valorx/valory